import { statsRouter } from "./routes/stats";

require("dotenv").config();

import { setupGitlab } from "./utils/gitlab";
import { releasesRouter } from "./routes/releases";
import { blacklistsRouter } from "./routes/blacklist";

import swaggerUi from "swagger-ui-express";
import express from "express";
import { connectToRedis } from "./utils/redis";

const swaggerDocument = require("./swagger.json");
const cors = require("cors");

export const BASE_API_URL = "/api/v2";
const app = express();

app.use(cors());

app.use(express.json());
app.use(statsRouter());
app.use(releasesRouter());
app.use(blacklistsRouter());
app.get("/api-docs/index.html", (req, res) => {
    res.redirect("/api-docs");
});
app.use("/api-docs", swaggerUi.serve, swaggerUi.setup(swaggerDocument));

app.get("/", (req, res) => {
    return res.redirect("/api-docs");
});

app.listen(3000, async () => {
    setupGitlab();
    await connectToRedis();

    console.log("Server is running on port 3000");
});

export default app;
