import { BASE_API_URL } from "../app";
import express from "express";
import { getMagmaReleaseByTag, gitlab } from "../utils/gitlab";
import { BlacklistEntry } from "../types/blacklistEntry";
import { versionToRepoName } from "../versions";

export function blacklistsRouter() {
    const router = express.Router();

    router.get(
        BASE_API_URL + "/git/check/:version/:first/:second",
        async (req, res, next) => {
            const repo = versionToRepoName(req.params.version);
            const commit1 = req.params.first;
            const commit2 = req.params.second;

            if (!repo) {
                res.status(404).json({ error: "Version not found" });
                return;
            }

            if (!commit1 || !commit2) {
                res.status(404).json({ error: "Error!" });
                return;
            }

            const release1 = await getMagmaReleaseByTag(repo, commit1);
            const release2 = await getMagmaReleaseByTag(repo, commit2);

            if (!release1 || !release2) {
                res.status(200).json(false);
                return;
            }

            const newer =
                new Date(release1.created_at) >= new Date(release2.created_at);
            res.status(200).json(newer);
        },
    );

    // Get all releases
    router.get(
        BASE_API_URL + "/:version/blacklist/:type/",
        async (req, res, next) => {
            const repo = versionToRepoName(req.params.version);
            const type = req.params.type;
            if (!repo) {
                res.status(404).json({ error: "Version not found" });
                return;
            }

            switch (type.trim().toLowerCase()) {
                case "mods":
                case "plugins":        
                    let show = await gitlab.RepositoryFiles.showRaw(encodeURI(`magmafoundation/Compatibility`), "blacklist.json");

                    const local: BlacklistEntry[] = JSON.parse(show);
                    const entries = local.filter(x => x.version == repo && x.type == type);
                    res.status(200).json(entries);
                    break;
                default:
                    res.status(404).json({ error: "Wrong type given" });
                    break;
            }
        },
    );


    return router;
}