import { BASE_API_URL } from "../app";
import express from "express";
import { getMagmaReleaseByTag, getMagmaReleases } from "../utils/gitlab";
import { ALL_VERSIONS, LATEST_RELEASE, versionToRepoName } from "../versions";

export function releasesRouter() {
    const router = express.Router();

    // Get all versions available
    router.get(BASE_API_URL + "/allVersions", async (req, res) => {
        res.json(Object.keys(ALL_VERSIONS));

    });

    // Get Latest version available
    router.get(BASE_API_URL + "/latestVersion", async (req, res) => {
        res.json(LATEST_RELEASE);
    });

    // Get all releases
    router.get(BASE_API_URL + "/:version", async (req, res) => {
        const repo = versionToRepoName(req.params.version);
        if (!repo) {
            res.status(404).json({ error: "Version Not found" });
            return;
        }
        res.json(await getMagmaReleases(repo));
    });

    // Get the latest release
    router.get(BASE_API_URL + "/:version/latest", async (req, res) => {
        const repo = versionToRepoName(req.params.version);
        if (!repo) {
            res.status(404).json({ error: "Version Not found" });
            return;
        }
        res.json((await getMagmaReleases(repo))[0]);
    });

    // Redirect to the download of the latest release
    router.get(BASE_API_URL + "/:version/latest/download", async (req, res) => {
        const repo = versionToRepoName(req.params.version);
        if (!repo) {
            res.status(404).json({ error: "Version Not found" });
            return;
        }
        res.redirect((await getMagmaReleases(repo))[0].link);
    });

    // Get the latest release by tag
    router.get(BASE_API_URL + "/:version/latest/:tag", async (req, res) => {
        const repo = versionToRepoName(req.params.version);
        if (!repo) {
            res.status(404).json({ error: "Version Not found" });
            return;
        }

        const release = await getMagmaReleaseByTag(repo, req.params.tag);
        if (!release) {
            res.status(404).json({ error: "Tag Not found" });
            return;
        }
        res.json(release);
    });

    // Redirect to the download of the latest release by tag
    router.get(
        BASE_API_URL + "/:version/latest/:tag/download",
        async (req, res) => {
            const repo = versionToRepoName(req.params.version);
            if (!repo) {
                res.status(404).json({ error: "Version Not found" });
                return;
            }

            const release = await getMagmaReleaseByTag(repo, req.params.tag);
            if (!release) {
                res.status(404).json({ error: "Tag Not found" });
                return;
            }

            res.redirect(release.link);
        },
    );

    return router;
}
