import { createClient } from "redis";

const client = createClient({
    url: process.env.REDIS_URL,
});

export async function connectToRedis() {
    try {
        console.log("Connecting to redis...", process.env.REDIS_URL);
        await client.connect();
        console.log("Redis connected");
    } catch (error) {
        console.log("Redis connection error", error);
    }
}

type provider<T> = () => Promise<T>;

export default async function remember<T>(
    key: string,
    r: provider<T>,
    ttl: number = 150,
): Promise<T> {
    return new Promise<T>(async (resolve, reject) => {
        if (await client.exists(key)) {
            const obj: string = await client.get(key);
            return resolve(JSON.parse(obj));
        }

        const result = await r();
        if (result != null) {
            await client.set(key, JSON.stringify(result), { EX: ttl });
        }
        return resolve(result);
    });
}
